[Libreoffice-commits] .: dmake/dbug dmake/dmake.c dmake/dmstring.c dmake/make.c dmake/path.c dmake/rulparse.c dmake/sysintf.c guw/guw.cc solenv/bin

Caolán McNamara caolan at kemper.freedesktop.org
Sun Dec 5 09:18:42 PST 2010


 dmake/dbug/dbug/dbug.c                            |    2 
 dmake/dmake.c                                     |    2 
 dmake/dmstring.c                                  |    2 
 dmake/make.c                                      |    2 
 dmake/path.c                                      |    2 
 dmake/rulparse.c                                  |    2 
 dmake/sysintf.c                                   |    2 
 guw/guw.cc                                        |    2 
 solenv/bin/modules/installer/control.pm           |   12 ++---
 solenv/bin/modules/installer/javainstaller.pm     |    4 -
 solenv/bin/modules/installer/packagepool.pm       |    8 +--
 solenv/bin/modules/installer/regmerge.pm          |   16 +++---
 solenv/bin/modules/installer/scpzipfiles.pm       |    4 -
 solenv/bin/modules/installer/scriptitems.pm       |   10 ++--
 solenv/bin/modules/installer/servicesfile.pm      |   52 +++++++++++-----------
 solenv/bin/modules/installer/windows/idtglobal.pm |   10 ++--
 solenv/bin/modules/installer/windows/msiglobal.pm |   38 ++++++++--------
 solenv/bin/modules/installer/windows/sign.pm      |    4 -
 solenv/bin/modules/installer/worker.pm            |    2 
 solenv/bin/modules/installer/xpdinstaller.pm      |   12 ++---
 solenv/bin/modules/packager/work.pm               |    2 
 solenv/bin/transform_description.pl               |    2 
 22 files changed, 96 insertions(+), 96 deletions(-)

New commits:
commit e46d57fd91611956acfcf124a0b4f294ae786bcd
Author: Takeshi Abe <tabe at fixedpoint.jp>
Date:   Sat Dec 4 12:39:00 2010 +0900

    Replace all occured, occurance etc.

diff --git a/dmake/dbug/dbug/dbug.c b/dmake/dbug/dbug/dbug.c
index eb2c5bc..c866cf7 100644
--- a/dmake/dbug/dbug/dbug.c
+++ b/dmake/dbug/dbug/dbug.c
@@ -235,7 +235,7 @@ LOCAL BOOLEAN DoProfile ();	/* Check if profiling is enabled */
 
                 /* Supplied in Sys V runtime environ */
 LOCAL char *strtok ();		/* Break string into tokens */
-LOCAL char *strrchr ();		/* Find last occurance of char */
+LOCAL char *strrchr ();		/* Find last occurrence of char */
 
 /*
  *	The following local variables are used to hold the state information
diff --git a/dmake/dmake.c b/dmake/dmake.c
index 7fcbf73..aee84cd 100644
--- a/dmake/dmake.c
+++ b/dmake/dmake.c
@@ -292,7 +292,7 @@ char **argv;
                  HASHPTR hp;
                  /* This cleans the .SILENT setting */
                  hp = Def_macro(".SILENT", "", M_EXPANDED);
-                 /* This overrides the bitmask for further occurences of
+                 /* This overrides the bitmask for further occurrences of
                   * .SILENT to "no bits allowed", see bit variables in the
                   * set_macro_value() definition in dag.c.
                   * The bitmask is already set by Create_macro_vars() in
diff --git a/dmake/dmstring.c b/dmake/dmstring.c
index 207e75c..c64f503 100644
--- a/dmake/dmstring.c
+++ b/dmake/dmstring.c
@@ -200,7 +200,7 @@ char *str;
 PUBLIC char *
 DmStrPbrk( s1, s2 )/*
 ====================
-   find first occurence of char in s2 in string s1.
+   find first occurrence of char in s2 in string s1.
    Returns a pointer to the first occurrence.  NOTE '\0' is considered part
    of s2 and a pointer to it is returned if no other chars match. */
 
diff --git a/dmake/make.c b/dmake/make.c
index 93878c4..a948c75 100644
--- a/dmake/make.c
+++ b/dmake/make.c
@@ -1254,7 +1254,7 @@ Exec_commands( cp )/*
 
   The function returns 0, if the command is executed and has successfully
   returned, and it returns 1 if the command is executing but has not yet
-  returned or -1 if an error occured (Return value from Do_cmnd()).
+  returned or -1 if an error occurred (Return value from Do_cmnd()).
 
   Macros that are found in recipe lines are expanded in this function, in
   parallel builds this can mean they are expanded before the previous recipe
diff --git a/dmake/path.c b/dmake/path.c
index 9520686..39c66e3 100644
--- a/dmake/path.c
+++ b/dmake/path.c
@@ -181,7 +181,7 @@ char *path;
 
 #ifdef HAVE_DRIVE_LETTERS
 
-   /* Change all occurences from DirBrkStr to *DirSepStr. This assumes
+   /* Change all occurrences from DirBrkStr to *DirSepStr. This assumes
     * that when HAVE_DRIVE_LETTERS is set the directory separator is
     * either '\' or '/'. */
    if (*DirSepStr == '/')
diff --git a/dmake/rulparse.c b/dmake/rulparse.c
index 4d1bc0b..fe1a62e 100644
--- a/dmake/rulparse.c
+++ b/dmake/rulparse.c
@@ -1194,7 +1194,7 @@ CELLPTR prereq;
     * definitions for the %-target members are stored in the prerequisites
     * list of the master target. */
    /* This relies on target->ce_prq being NULL if this is the first
-    * occurence of this %-target and therefore not yet having a %-target
+    * occurrence of this %-target and therefore not yet having a %-target
     * master. */
    match = FALSE;
    for(edl=target->ce_prq; !match && edl != NIL(LINK); edl=edl->cl_next) {
diff --git a/dmake/sysintf.c b/dmake/sysintf.c
index 528178a..dd95b40 100644
--- a/dmake/sysintf.c
+++ b/dmake/sysintf.c
@@ -278,7 +278,7 @@ int     last;	/* Last recipe line in target. */
       DB_RETURN( 0 );
    }
 
-   /* Stop making the rest of the recipies for this target if an error occured
+   /* Stop making the rest of the recipies for this target if an error occurred
     * but the Continue (-k) flag is set to build as much as possible. */
    if ( target->ce_attr & A_ERROR ) {
       if ( last ) {
diff --git a/guw/guw.cc b/guw/guw.cc
index ea7c84d..ef6e5eb 100644
--- a/guw/guw.cc
+++ b/guw/guw.cc
@@ -641,7 +641,7 @@ void rep_subn_cyg(string &argument)
   regfree(&re);
 }
 
-// Replace all occurences of subexpression number "subexp" with "repl"
+// Replace all occurrences of subexpression number "subexp" with "repl"
 void rep_subn( string &argument, const char *pattern, int subexp, const char repl)
 {
   int status, pos=0;
diff --git a/solenv/bin/modules/installer/control.pm b/solenv/bin/modules/installer/control.pm
index bd9c2d5..1b2ea07 100644
--- a/solenv/bin/modules/installer/control.pm
+++ b/solenv/bin/modules/installer/control.pm
@@ -341,11 +341,11 @@ sub check_logfile
         # Errors are all errors, but not the Windows installer table "Error.idt"
 
         my $compareline = $line;
-        $compareline =~ s/Error\.idt//g;	# removing all occurences of "Error.idt"
-        $compareline =~ s/Error\.mlf//g;	# removing all occurences of "Error.mlf"
-        $compareline =~ s/Error\.ulf//g;	# removing all occurences of "Error.ulf"
-        $compareline =~ s/Error\.idl//g;	# removing all occurences of "Error.idl"
-        $compareline =~ s/Error\.html//g;	# removing all occurences of "Error.html"
+        $compareline =~ s/Error\.idt//g;	# removing all occurrences of "Error.idt"
+        $compareline =~ s/Error\.mlf//g;	# removing all occurrences of "Error.mlf"
+        $compareline =~ s/Error\.ulf//g;	# removing all occurrences of "Error.ulf"
+        $compareline =~ s/Error\.idl//g;	# removing all occurrences of "Error.idl"
+        $compareline =~ s/Error\.html//g;	# removing all occurrences of "Error.html"
         
         if ( $compareline =~ /\bError\b/i )
         {
@@ -358,7 +358,7 @@ sub check_logfile
     {
         my $line = "\n*********************************************************************\n";
         push(@output, $line);
-        $line = "ERROR: The following errors occured in packaging process:\n\n";
+        $line = "ERROR: The following errors occurred in packaging process:\n\n";
         push(@output, $line);
 
         for ( my $i = 0; $i <= $#errors; $i++ )
diff --git a/solenv/bin/modules/installer/javainstaller.pm b/solenv/bin/modules/installer/javainstaller.pm
index 49aedf4..7041897 100644
--- a/solenv/bin/modules/installer/javainstaller.pm
+++ b/solenv/bin/modules/installer/javainstaller.pm
@@ -374,7 +374,7 @@ sub convert_licenstring
 #######################################################
 # Adding the license file into the java file
 # In the template java file there are two
-# occurences of INSTALLSDK_GUI_LICENSE
+# occurrences of INSTALLSDK_GUI_LICENSE
 # and INSTALLSDK_CONSOLE_LICENSE
 #######################################################
 
@@ -425,7 +425,7 @@ sub make_systemcall
     {
         $infoline = "ERROR: $systemcall\n";
         push( @installer::globals::logfileinfo, $infoline);
-        $error_occured = 1;
+        $error_occurred = 1;
     }
     else
     {
diff --git a/solenv/bin/modules/installer/regmerge.pm b/solenv/bin/modules/installer/regmerge.pm
index 688fb9e..f936c0c 100644
--- a/solenv/bin/modules/installer/regmerge.pm
+++ b/solenv/bin/modules/installer/regmerge.pm
@@ -219,20 +219,20 @@ sub merge_files
     my $prefix = $databasefile->{'NativeServicesURLPrefix'};
     # TODO: "NativeServicesURLPrefix" or "JavaServicesURLPrefix"
     
-    my $error_occured = 0;
+    my $error_occurred = 0;
 
     for ( my $i = 0; $i <= $#{$registerfiles}; $i++ )
     {	
         my $registerfile = $databasedir . $installer::globals::separator . $i . ".tmp";
-        open (IN, '<', $registerfiles->[$i]) or $error_occured = 1;
-        open (OUT, '>', $registerfile) or $error_occured = 1;
+        open (IN, '<', $registerfiles->[$i]) or $error_occurred = 1;
+        open (OUT, '>', $registerfile) or $error_occurred = 1;
         while (<IN>)
         {
             s/^ComponentName=/ComponentName=$prefix/;
-            print OUT $_ or $error_occured = 1;
+            print OUT $_ or $error_occurred = 1;
         }
-        close IN or $error_occured = 1;
-        close OUT or $error_occured = 1;
+        close IN or $error_occurred = 1;
+        close OUT or $error_occurred = 1;
 
         my $systemcall = $regmergefile . " -v " . $databasedest . " " . $registerfile . " 2\>\&1 |";
         
@@ -271,7 +271,7 @@ sub merge_files
         {
             $infoline = "ERROR: $systemcall\n";
             push( @installer::globals::logfileinfo, $infoline);
-            $error_occured = 1;
+            $error_occurred = 1;
         }
         else
         {
@@ -280,7 +280,7 @@ sub merge_files
         }		
     }
     
-    return $error_occured;
+    return $error_occurred;
 }
 
 ################################################################
diff --git a/solenv/bin/modules/installer/scpzipfiles.pm b/solenv/bin/modules/installer/scpzipfiles.pm
index f4e500f..8854b3d 100644
--- a/solenv/bin/modules/installer/scpzipfiles.pm
+++ b/solenv/bin/modules/installer/scpzipfiles.pm
@@ -45,7 +45,7 @@ sub replace_all_ziplistvariables_in_file
     {
         my $line = ${$fileref}[$i];
 
-        if ( $line =~ /^.*\$\{\w+\}.*$/ )	# only occurence of ${abc}
+        if ( $line =~ /^.*\$\{\w+\}.*$/ )	# only occurrence of ${abc}
         {			
             my $key;
 
@@ -73,7 +73,7 @@ sub replace_all_ziplistvariables_in_rtffile
     {
         my $line = ${$fileref}[$i];
 
-        if ( $line =~ /^.*\$\\\{\w+\\\}.*$/ )	# only occurence of $\{abc\}
+        if ( $line =~ /^.*\$\\\{\w+\\\}.*$/ )	# only occurrence of $\{abc\}
         {			
             for ( my $j = 0; $j <= $#{$variablesref}; $j++ )
             {
diff --git a/solenv/bin/modules/installer/scriptitems.pm b/solenv/bin/modules/installer/scriptitems.pm
index 6ba76fe..d133770 100644
--- a/solenv/bin/modules/installer/scriptitems.pm
+++ b/solenv/bin/modules/installer/scriptitems.pm
@@ -1335,7 +1335,7 @@ sub remove_Files_Without_Sourcedirectory
 
     my $infoline;
     
-    my $error_occured = 0;
+    my $error_occurred = 0;
     my @missingfiles = ();
     push(@missingfiles, "ERROR: The following files could not be found: \n");
     
@@ -1360,7 +1360,7 @@ sub remove_Files_Without_Sourcedirectory
                     push( @installer::globals::logfileinfo, $infoline);
 
                     push(@missingfiles, "ERROR: File not found: $filename\n");	
-                    $error_occured = 1;
+                    $error_occurred = 1;
 
                     next;	# removing this file from list, if sourcepath is empty
                 }
@@ -1372,7 +1372,7 @@ sub remove_Files_Without_Sourcedirectory
                         push( @installer::globals::logfileinfo, $infoline);
 
                         push(@missingfiles, "ERROR: File not found: $filename\n");	
-                        $error_occured = 1;
+                        $error_occurred = 1;
 
                         next;	# removing this file from list, if sourcepath is empty		
                     }
@@ -1395,7 +1395,7 @@ sub remove_Files_Without_Sourcedirectory
     $infoline = "\n";
     push( @installer::globals::logfileinfo, $infoline);
 
-    if ( $error_occured )
+    if ( $error_occurred )
     {
         for ( my $i = 0; $i <= $#missingfiles; $i++ ) { print "$missingfiles[$i]"; }
         installer::exiter::exit_program("ERROR: Missing files", "remove_Files_Without_Sourcedirectory");
@@ -2025,7 +2025,7 @@ sub quoting_illegal_filenames
 }
 
 ############################################################################
-# Removing multiple occurences of same module.
+# Removing multiple occurrences of same module.
 ############################################################################
 
 sub optimize_list
diff --git a/solenv/bin/modules/installer/servicesfile.pm b/solenv/bin/modules/installer/servicesfile.pm
index 417066a..c113be6 100644
--- a/solenv/bin/modules/installer/servicesfile.pm
+++ b/solenv/bin/modules/installer/servicesfile.pm
@@ -129,18 +129,18 @@ sub register_unocomponents
 
     installer::logger::include_header_into_logfile("Registering UNO components:");
 
-    my $error_occured = 0;
+    my $error_occurred = 0;
     my $filestring = "";
     for ( my $i = 0; $i <= $#{$unocomponents}; ++$i )
     {
-        my $local_error1_occured = 0;
-        my $local_error2_occured = 0;
+        my $local_error1_occurred = 0;
+        my $local_error2_occurred = 0;
         
         my $sourcepath = make_file_url(${$unocomponents}[$i]->{'sourcepath'});
         my $urlprefix = ${$unocomponents}[$i]->{'NativeServicesURLPrefix'};
         if (defined($urlprefix))
         {
-            $local_error1_occured = call_regcomp($regcompfileref, $servicesfile, $sourcepath, $urlprefix);
+            $local_error1_occurred = call_regcomp($regcompfileref, $servicesfile, $sourcepath, $urlprefix);
         }
         else
         {
@@ -150,14 +150,14 @@ sub register_unocomponents
         if (length($filestring) > $installer::globals::unomaxservices ||
             ($i == $#{$unocomponents} && $filestring ne ""))
         {
-            $local_error2_occured = call_regcomp($regcompfileref, $servicesfile, $filestring, $nativeservicesurlprefix);
+            $local_error2_occurred = call_regcomp($regcompfileref, $servicesfile, $filestring, $nativeservicesurlprefix);
             $filestring = "";
         }
         
-        if (( $local_error1_occured ) || ( $local_error2_occured )) { $error_occured = 1; }
+        if (( $local_error1_occurred ) || ( $local_error2_occured )) { $error_occured = 1; }
     }
     
-    return $error_occured;
+    return $error_occurred;
 }
 
 sub call_regcomp
@@ -165,7 +165,7 @@ sub call_regcomp
     my ($regcompfileref, $servicesfile, $filestring, $urlprefix) = @_;
     my @regcompoutput = ();
 
-    my $error_occured = 0;
+    my $error_occurred = 0;
 
     my $systemcall = "$$regcompfileref -register -r ".fix_cygwin_path($servicesfile)." -c "  . $installer::globals::quote . $filestring . $installer::globals::quote . " -wop=" . $installer::globals::quote . $urlprefix . $installer::globals::quote . " 2\>\&1 |";
 
@@ -184,7 +184,7 @@ sub call_regcomp
     {
         $infoline = "ERROR: $systemcall\n";
         push( @installer::globals::logfileinfo, $infoline);
-        $error_occured = 1;
+        $error_occurred = 1;
     }
     else
     {
@@ -192,7 +192,7 @@ sub call_regcomp
         push( @installer::globals::logfileinfo, $infoline);
     }
     
-    return $error_occured;
+    return $error_occurred;
 }
 
 ################################################################
@@ -210,7 +210,7 @@ sub register_javacomponents
     installer::pathanalyzer::get_path_from_fullqualifiedname($ure_internal_java_dir_ref);
     if ( $$ure_internal_java_dir_ref eq "" ) { installer::exiter::exit_program("Could not determine URE_INTERNAL_JAVA_DIR when registering Java components!", "register_javacomponents"); }
 
-    my $error_occured = 0;
+    my $error_occurred = 0;
 
     my $do_register = 1;
     if (!( $installer::globals::solarjava )) { $do_register = 0; }
@@ -245,7 +245,7 @@ sub register_javacomponents
                 if ($returnvalue)
                 {
                     $infoline = "ERROR: $systemcall\n";
-                    $error_occured = 1;
+                    $error_occurred = 1;
                 }
                 else
                 {
@@ -263,7 +263,7 @@ sub register_javacomponents
         }
     }
     
-    return $error_occured;
+    return $error_occurred;
 }
 
 
@@ -311,7 +311,7 @@ sub register_pythoncomponents
 
     installer::logger::include_header_into_logfile("Registering python UNO components:");
 
-    my $error_occured = 0;
+    my $error_occurred = 0;
     my $counter = 0;
 
     my $systemcall = "";
@@ -386,7 +386,7 @@ sub register_pythoncomponents
                 {
                     $infoline = "ERROR: $systemcall\n";
                     push( @installer::globals::logfileinfo, $infoline);
-                    $error_occured = 1;
+                    $error_occurred = 1;
                 }
                 else
                 {
@@ -402,7 +402,7 @@ sub register_pythoncomponents
         }
     }
     
-    return $error_occured;
+    return $error_occurred;
 }
 
 ################################################################
@@ -454,15 +454,15 @@ sub register_all_components
         }
     }
     
-    $uno_error_occured = 0;
-    $java_error_occured = 0;
-    $python_error_occured = 0;
+    $uno_error_occurred = 0;
+    $java_error_occurred = 0;
+    $python_error_occurred = 0;
 
-    if ( $#unocomponents > -1 ) { $uno_error_occured = register_unocomponents($allvariableshashref, \@unocomponents, $regcompfileref, $servicesfile, $nativeservicesurlprefix); }
-    if ( $#javacomponents > -1 ) { $java_error_occured = register_javacomponents($allvariableshashref, \@javacomponents, $regcompfileref, $servicesfile, $regcomprdb, $javaservicesurlprefix); }
-    if ( $#pythoncomponents > -1 ) { $python_error_occured = register_pythoncomponents(\@pythoncomponents, $regcompfileref, $servicesfile, $includepatharrayref); }
+    if ( $#unocomponents > -1 ) { $uno_error_occurred = register_unocomponents($allvariableshashref, \@unocomponents, $regcompfileref, $servicesfile, $nativeservicesurlprefix); }
+    if ( $#javacomponents > -1 ) { $java_error_occurred = register_javacomponents($allvariableshashref, \@javacomponents, $regcompfileref, $servicesfile, $regcomprdb, $javaservicesurlprefix); }
+    if ( $#pythoncomponents > -1 ) { $python_error_occurred = register_pythoncomponents(\@pythoncomponents, $regcompfileref, $servicesfile, $includepatharrayref); }
         
-    if ( $uno_error_occured || $java_error_occured || $python_error_occured ) { $registererrorflag = 1; }
+    if ( $uno_error_occurred || $java_error_occured || $python_error_occured ) { $registererrorflag = 1; }
     
     return $registererrorflag;
 }
@@ -741,7 +741,7 @@ sub collect_all_services_gids
     my ($filesarrayref) = @_;
 
     my @databasegids = ();
-    my $error_occured = 0;
+    my $error_occurred = 0;
     my @error_files = ();
 
     for ( my $i = 0; $i <= $#{$filesarrayref}; $i++ )
@@ -756,11 +756,11 @@ sub collect_all_services_gids
         else
         {
             push(@error_files, $onefile->{'gid'});
-            $error_occured = 1;
+            $error_occurred = 1;
         }
     }
     
-    if ( $error_occured )
+    if ( $error_occurred )
     {
         my $infoline = "ERROR: Style UNO_COMPONENT is set, but no RegistryID is assigned!\n";
         push( @installer::globals::logfileinfo, $infoline);
diff --git a/solenv/bin/modules/installer/windows/idtglobal.pm b/solenv/bin/modules/installer/windows/idtglobal.pm
index 44b64ec..1abeeb6 100644
--- a/solenv/bin/modules/installer/windows/idtglobal.pm
+++ b/solenv/bin/modules/installer/windows/idtglobal.pm
@@ -2064,7 +2064,7 @@ sub get_customaction_position
 
 ##########################################################################
 # Setting the position of CustomActions in sequence tables.
-# Replacing all occurences of "POSITIONTEMPLATE_"
+# Replacing all occurrences of "POSITIONTEMPLATE_"
 ##########################################################################
 
 sub set_positions_in_table
@@ -2074,7 +2074,7 @@ sub set_positions_in_table
     my $infoline = "\nSetting positions in table \"$tablename\".\n"; 
     push(@installer::globals::logfileinfo, $infoline);
 
-    # Step 1: Resolving all occurences of "POSITIONTEMPLATE_end"
+    # Step 1: Resolving all occurrences of "POSITIONTEMPLATE_end"
 
     my $lastposition = get_last_position_in_sequencetable($sequencetable);
 
@@ -2090,9 +2090,9 @@ sub set_positions_in_table
         }
     }
     
-    # Step 2: Resolving all occurences of "POSITIONTEMPLATE_abc" or "POSITIONTEMPLATE_behind_abc"
+    # Step 2: Resolving all occurrences of "POSITIONTEMPLATE_abc" or "POSITIONTEMPLATE_behind_abc"
     # where abc is the name of the reference Custom Action.
-    # This has to be done, until there is no more occurence of POSITIONTEMPLATE (success)
+    # This has to be done, until there is no more occurrence of POSITIONTEMPLATE (success)
     # or there is no replacement in one circle (failure).
     
     my $template_exists = 0;
@@ -2147,7 +2147,7 @@ sub set_positions_in_table
         }
     } while (( $template_exists ) && ( $template_replaced ));
 
-    # An error occured, because templates still exist, but could not be replaced.
+    # An error occurred, because templates still exist, but could not be replaced.
     # Reason:
     # 1. Wrong name of CustomAction in scp2 (typo?)
     # 2. Circular dependencies of CustomActions (A after B and B after A)
diff --git a/solenv/bin/modules/installer/windows/sign.pm b/solenv/bin/modules/installer/windows/sign.pm
index fc27367..629ddba 100644
--- a/solenv/bin/modules/installer/windows/sign.pm
+++ b/solenv/bin/modules/installer/windows/sign.pm
@@ -629,9 +629,9 @@ sub cabinet_cosistency_check
                 }		
                 else
                 {
-                    $infoline = "ERROR: Problem occured calling diff.exe (File: $lastfile)\n";
+                    $infoline = "ERROR: Problem occurred calling diff.exe (File: $lastfile)\n";
                     push( @installer::globals::logfileinfo, $infoline);								
-                    installer::exiter::exit_program("ERROR: Problem occured calling diff.exe (File: $lastfile) !", "cabinet_cosistency_check");
+                    installer::exiter::exit_program("ERROR: Problem occurred calling diff.exe (File: $lastfile) !", "cabinet_cosistency_check");
                 }
             }
         }		
diff --git a/solenv/bin/modules/installer/worker.pm b/solenv/bin/modules/installer/worker.pm
index 0e327a7..058241d 100644
--- a/solenv/bin/modules/installer/worker.pm
+++ b/solenv/bin/modules/installer/worker.pm
@@ -475,7 +475,7 @@ sub analyze_and_save_logfile
     
     if ( $installer::globals::creating_windows_installer_patch ) { $installer::globals::creating_windows_installer_patch = 0; }
     
-    # Exiting the packaging process, if an error occured.
+    # Exiting the packaging process, if an error occurred.
     # This is important, to get an error code "-1", if an error was found in the log file,
     # that did not break the packaging process
     
diff --git a/solenv/bin/modules/installer/xpdinstaller.pm b/solenv/bin/modules/installer/xpdinstaller.pm
index 8b0df5d..fd08ed9 100644
--- a/solenv/bin/modules/installer/xpdinstaller.pm
+++ b/solenv/bin/modules/installer/xpdinstaller.pm
@@ -443,8 +443,8 @@ sub get_forceintoupdate_value
 }
 
 ###################################################
-# Substituting all occurences of "<" by "&lt;" 
-# and all occurences of ">" by "&gt;"
+# Substituting all occurrences of "<" by "&lt;" 
+# and all occurrences of ">" by "&gt;"
 ###################################################
 
 sub replace_brackets_in_string
@@ -458,7 +458,7 @@ sub replace_brackets_in_string
 }
 
 ###################################################
-# Substituting all occurences of "\uUXYZ" by 
+# Substituting all occurrences of "\uUXYZ" by 
 # "&#xUXYZ;", because the use xml saxparser does
 # not know anything about this encoding. Therfore
 # the xml file can keep standard encoding "UTF-8"
@@ -884,7 +884,7 @@ sub make_systemcall
     {
         $infoline = "ERROR: $systemcall\n";
         push( @installer::globals::logfileinfo, $infoline);
-        $error_occured = 1;
+        $error_occurred = 1;
     }
     else
     {
@@ -927,13 +927,13 @@ sub make_systemcall_allowing_error
         {
             $infoline = "WARNING: Failed system call:  $systemcall\n";
             push( @installer::globals::logfileinfo, $infoline);
-            $error_occured = 1;
+            $error_occurred = 1;
         }
         else
         {
             $infoline = "ERROR: $systemcall\n";
             push( @installer::globals::logfileinfo, $infoline);
-            $error_occured = 1;			
+            $error_occurred = 1;			
         }
     }
     else
diff --git a/solenv/bin/modules/packager/work.pm b/solenv/bin/modules/packager/work.pm
index ace8aef..158e921 100644
--- a/solenv/bin/modules/packager/work.pm
+++ b/solenv/bin/modules/packager/work.pm
@@ -293,7 +293,7 @@ sub do_broadcast
     print "cmd_bcst -s 18 \@$tmpfile_name\n";
     unlink "$tmpfile_name";
 
-    if ( $returnvalue )	# an error occured
+    if ( $returnvalue )	# an error occurred
     {
         if (!($packager::globals::ignoreerrors)) { packager::exiter::exit_program("ERROR: Packing not successful!", "do_broadcast"); }
     }
diff --git a/solenv/bin/transform_description.pl b/solenv/bin/transform_description.pl
index b0d0ce7..f1ccc0b 100644
--- a/solenv/bin/transform_description.pl
+++ b/solenv/bin/transform_description.pl
@@ -130,7 +130,7 @@ sub explain
     print STDOUT "\n";
     print STDOUT "  The following transformations are done at the moment:\n";
     print STDOUT "  - duplicate all lines containing #LANG#, for ever token of \$WITH_LANG\n";
-    print STDOUT "    replacing every occurance of \$LANG with a token\n";
+    print STDOUT "    replacing every occurrence of \$LANG with a token\n";
     print STDOUT "\n";
     print STDOUT "  And yes, the functionality of this script should be\n";
     print STDOUT "  - moved to solenv/inc/tg_ext.mk\n";


More information about the Libreoffice-commits mailing list
diff --git a/solenv/bin/modules/installer/packagepool.pm b/solenv/bin/modules/installer/packagepool.pm
index d603dd5..6c18743 100644
--- a/solenv/bin/modules/installer/packagepool.pm
+++ b/solenv/bin/modules/installer/packagepool.pm
@@ -743,7 +743,7 @@ sub package_is_up_to_date
         log_pool_info(0);
         
         # removing new package from installation set
-        if ( $newpackagepath ne "" ) { remove_package_from_installset($newpackagepath); } 	# A file was copied and a problem occured with pooling
+        if ( $newpackagepath ne "" ) { remove_package_from_installset($newpackagepath); } 	# A file was copied and a problem occurred with pooling
         
         $package_is_up_to_date = 4;	# repeat this package
         return $package_is_up_to_date;
@@ -756,7 +756,7 @@ sub package_is_up_to_date
         log_pool_info(1);
 
         # removing new package from installation set
-        if ( $newpackagepath ne "" ) { remove_package_from_installset($newpackagepath); } 	# A file was copied and a problem occured with pooling
+        if ( $newpackagepath ne "" ) { remove_package_from_installset($newpackagepath); } 	# A file was copied and a problem occurred with pooling
 
         $package_is_up_to_date = 4;	# repeat this package
         return $package_is_up_to_date;
@@ -914,7 +914,7 @@ sub put_content_into_pool
     }
     
     # Before the new package is renamed in the pool, it has to be checked, if this process still has the lock for this package.
     # Check, if lock file still exists and if this process is the owner. Otherwise a pool error occured.
     if ( ! -f $installer::globals::poollockfilename )
     {
         unlink $uniquedestination;  # removing file from pool
@@ -936,7 +936,7 @@ sub put_content_into_pool
     push( @installer::globals::logfileinfo, $infoline);
 
     # Before the lock file in the pool can be removed, it has to be checked, if this process is still the owner of this lock file.
     # Check, if lock file still exists and if this process is the owner. Otherwise a pool error occured.
     if ( ! -f $installer::globals::poollockfilename )
     {
         log_pool_info(0);
@@ -914,7 +914,7 @@ sub put_content_into_pool
     
     # Before the new package is renamed in the pool, it has to be checked, if this process still has the lock for this package.
-    # Check, if lock file still exists and if this process is the owner. Otherwise a pool error occured.
+    # Check, if lock file still exists and if this process is the owner. Otherwise a pool error occurred.
     if ( ! -f $installer::globals::poollockfilename )
     {
@@ -936,7 +936,7 @@ sub put_content_into_pool
 
     # Before the lock file in the pool can be removed, it has to be checked, if this process is still the owner of this lock file.
-    # Check, if lock file still exists and if this process is the owner. Otherwise a pool error occured.
+    # Check, if lock file still exists and if this process is the owner. Otherwise a pool error occurred.
     if ( ! -f $installer::globals::poollockfilename )
     {
diff --git a/solenv/bin/modules/installer/windows/msiglobal.pm b/solenv/bin/modules/installer/windows/msiglobal.pm
index 8e1f906..a627c17 100644
--- a/solenv/bin/modules/installer/windows/msiglobal.pm
+++ b/solenv/bin/modules/installer/windows/msiglobal.pm
@@ -1005,9 +1005,9 @@ sub create_transforms
         my $infoline = "Systemcall: $systemcall\n";
         push( @installer::globals::logfileinfo, $infoline);
         
         # Problem: msitran.exe in version 4.0 always returns "1", even if no failure occured.
         # Therefore it has to be checked, if this is version 4.0. If yes, if the mst file
         # exists and if it is larger than 0 bytes. If this is true, then no error occured.
         # File Version of msitran.exe: 4.0.6000.16384 has checksum: "b66190a70145a57773ec769e16777b29".
         # Same for msitran.exe from wntmsci12: "aa25d3445b94ffde8ef0c1efb77a56b8"
         
@@ -1052,13 +1052,13 @@ sub create_transforms
                     }
                     else
                     {
-                        $infoline = "Filesize indicates that an error occured.\n";
+                        $infoline = "Filesize indicates that an error occurred.\n";
                         push( @installer::globals::logfileinfo, $infoline);
                     }
                 }
                 else
                 {
-                    $infoline = "File $transformfile does not exist -> An error occured.\n";
+                    $infoline = "File $transformfile does not exist -> An error occurred.\n";
                     push( @installer::globals::logfileinfo, $infoline);					
                 }
             }
@@ -2076,8 +2076,8 @@ sub read_saved_mappings
     {
         my @errorlines = ();
         my $errorstring = "";
-        my $error_occured = 0;
-        my $file_error_occured = 0;
+        my $error_occurred = 0;
+        my $file_error_occurred = 0;
         my $dir_error = 0;
         
         my $idtdir = $installer::globals::previous_idt_dir;
@@ -2101,28 +2101,28 @@ sub read_saved_mappings
             
             if ( exists($installer::globals::savedmapping{"$2/$5"}))
             {
-                if ( ! $file_error_occured )
+                if ( ! $file_error_occurred )
                 {
                     $errorstring = "\nErrors in $idtfile: \n";
                     push(@errorlines, $errorstring);
                 }
                 $errorstring = "Duplicate savedmapping{" . "$2/$5}\n";
                 push(@errorlines, $errorstring);
-                $error_occured = 1;
-                $file_error_occured = 1;
+                $error_occurred = 1;
+                $file_error_occurred = 1;
             }
             
             if ( exists($installer::globals::savedrevmapping{$lc1}))
             {
-                if ( ! $file_error_occured )
+                if ( ! $file_error_occurred )
                 {
                     $errorstring = "\nErrors in $idtfile: \n";
                     push(@errorlines, $errorstring);
                 }
                 $errorstring = "Duplicate savedrevmapping{" . "$lc1}\n";
                 push(@errorlines, $errorstring);
-                $error_occured = 1;
-                $file_error_occured = 1;
+                $error_occurred = 1;
+                $file_error_occurred = 1;
             }
             
             my $shortname = $4 || '';
@@ -2136,15 +2136,15 @@ sub read_saved_mappings
 
             if (( $shortname ne '' ) && ( index($shortname, '~') > 0 ) && ( exists($installer::globals::savedrev83mapping{$shortname}) ))
             {
-                if ( ! $file_error_occured )
+                if ( ! $file_error_occurred )
                 {
                     $errorstring = "\nErrors in $idtfile: \n";
                     push(@errorlines, $errorstring);
                 }
                 $errorstring = "Duplicate savedrev83mapping{" . "$shortname}\n";
                 push(@errorlines, $errorstring);
-                $error_occured = 1;
-                $file_error_occured = 1;
+                $error_occurred = 1;
+                $file_error_occurred = 1;
             }
 
             $installer::globals::savedmapping{"$2/$5"} = "$1;$shortname";
@@ -2176,15 +2176,15 @@ sub read_saved_mappings
 
             if ( exists($installer::globals::saved83dirmapping{$1}) )
             {
-                if ( ! $dir_error_occured )
+                if ( ! $dir_error_occurred )
                 {
                     $errorstring = "\nErrors in $idtfile: \n";
                     push(@errorlines, $errorstring);
                 }
                 $errorstring = "Duplicate saved83dirmapping{" . "$1}\n";
                 push(@errorlines, $errorstring);
-                $error_occured = 1;
-                $dir_error_occured = 1;
+                $error_occurred = 1;
+                $dir_error_occurred = 1;
             }
 
             $installer::globals::saved83dirmapping{$1} = $4;
@@ -2196,7 +2196,7 @@ sub read_saved_mappings
 
         # Analyzing errors
         
-        if ( $error_occured )
+        if ( $error_occurred )
         {
             for ( my $i = 0; $i <= $#errorlines; $i++ )
             {
@@ -1005,9 +1005,9 @@ sub create_transforms
         push( @installer::globals::logfileinfo, $infoline);
         
-        # Problem: msitran.exe in version 4.0 always returns "1", even if no failure occured.
+        # Problem: msitran.exe in version 4.0 always returns "1", even if no failure occurred.
         # Therefore it has to be checked, if this is version 4.0. If yes, if the mst file
@@ -1005,9 +1005,9 @@ sub create_transforms
         # Therefore it has to be checked, if this is version 4.0. If yes, if the mst file
-        # exists and if it is larger than 0 bytes. If this is true, then no error occured.
+        # exists and if it is larger than 0 bytes. If this is true, then no error occurred.
         # File Version of msitran.exe: 4.0.6000.16384 has checksum: "b66190a70145a57773ec769e16777b29".
         # Same for msitran.exe from wntmsci12: "aa25d3445b94ffde8ef0c1efb77a56b8"